---
title: "Rendez vos revues de code plus efficaces !"
date: "2023-11-03"
authors: 
  - "cchaudier"
  - "tmichel"
slug: "rendez_vos_revues_de_code_plus-efficaces"
categories: 
  - "devops"
tags: 
  - "apprentissage"
  - "devops"
  - "froggit"
  - "gitlab"
image: "pre-commit1.jpg"
---

#### De la gestion du temps au déblocage, découvrez les secrets pour des revues de code plus efficaces.

<!-- truncate -->

Comme la plupart des entreprises, la revue de code chez GitLab prend une place importante dans leur flux de travail. Cependant, il est clair qu'en observant les résultats du sondage [_2020 Global DevSecOps_](https://about.gitlab.com/developer-survey/), on constate que la revue de code peut être une des raisons majeures qui mènent à un retard dans _les releases_ et une frustration globale. Une vaste majorité d'entreprises mènent des revues de code (certaines font même ça quotidiennement) mais cela est potentiellement une perte de temps.


Cependant, la revue de code peut être faite de manière efficace et je peux en parler en connaissance de cause car j'ai été mainteneur pendant 3 ans. Voici un aperçu de mon rituel éprouvée qui me permet de passer en revue et de fusionner du code rapidement et efficacement pour aider les autres à ne pas être bloqués à cause de moi. Bien entendu, ce rituel marche pour _moi_ mais il peut différer légèrement d'une personne à l'autre. Voici ce que je fais :

 

## 1\. La gestion du temps

Je commence ma journée par passer en revue les demandes de fusion. Je me donne une heure pour commencer et je m'astreint à cette tâche jusqu'à ce que ma _“to do list”_ Gitlab n'a plus de demande de fusion qui nécessite une vérification. J'aime bien faire ça le matin car c'est le moment de la journée où je suis le plus concentré et à même de faire les vérifications sans être trop distrait.

M'atteler aux revues après cette heure-ci est compliqué. J'ai d'autres tâches à effectuer également et une fois que j'ai vérifié toutes les demandes de fusion sur ma liste, je laisse ma liste tranquille jusqu'au lendemain. Bien évidemment, comme toute règle, on finit par l'enfreindre. Suivant la taille des demandes de fusion, \*_Je peux m'assurer de les vérifier avant que ma journée ne se termine pour être sûr que personne d'autre sur un autre fuseau horaire ne soit pas bloqué par celle-ci. \*_

 

## 2\. Débloquer les autres en premier

Devoir attendre X heures / jours avant d'obtenir un retour n'est pas l'idéal pour l'auteur d'une demande de fusion. Plus vite ils obtiennent un retour et plus vite la demande de fusion peut être effectuée et livrée. Faire attendre les auteurs ne fait que créer de l'incertitude et peut signifier que d'autres tâches sont retardées.

C'est la raison pour laquelle je trouve important d'examiner une demande de fusion aussi vite que je le peux. Chez Gitlab, ils ont pour objectif d'apporter une première réponse en 2 jours (_[2 day Service Level Objective](https://about.gitlab.com/handbook/engineering/workflow/code-review/#first-response-slo)_ en anglais) pour le retour de la part des personnes qui s'occupent de la revue de code. Pour ma part, j'essaye toujours de faire mieux que ça et d'apporter une première réponse dans la journée-même.

 

## 3\. Se concentrer sur le code, pas la fonctionnalité

Ce point pourrait susciter beaucoup de discussions : au lieu de se concentrer sur la fonctionnalité, concentrez-vous sur le code.

Un grand nombre de demandes de fusion que j'examine proviennent de différents groupes, avec des fonctionnalités que je ne comprend pas totalement ou avec des fonctionnalités que je ne peux pas tester. Je pourrais passer beaucoup de temps à lire le code d'une fonctionnalité et le problème pour comprendre de quoi il s'agit, mais cela signifie passer plus de temps à ne pas examiner le code de quelqu'un d'autre. De plus, si je faisais cela avec **toutes** les demandes de fusion, j'aurais du mal à m'en tenir à ma limite de temps.

Qui est le plus à même d'examiner la fonctionnalité du coup ? Le _product designer_ (UX) ou le _product manager_ comprennent tous les deux la fonctionnalité en cours de travail et sont plus compétents pour trouver des bugs et guider la fonctionnalité dans la bonne direction. Il est important que quelqu'un dans l'équipe UX examine la fonctionnalité pour s'assurer que cela correspond aux designs et à la vision qu'ils avaient imaginés pour la fonctionnalité. Si une demande de fusion n'a pas d'examen UX au moment où je dois l'examiner, je vais normalement demander à l'auteur (ou demander à un _product designer_ moi-même) que l'UX soit examiné avant que je fusionne la demande de fusion.

Cependant, ce point est aussi quelque chose auquel je ne tient pas toujours. Si une demande de fusion touche à une zone qui m'est familier et que je peux affirmer en voyant le code qu'un bug est présent, je vais le tester localement et fournir un maximum de _feedback_ pour aider l'auteur à comprendre le bug. Plus vous, en tant qu'examinateur, travaillez avec le code, plus il est simple de trouver des bugs dans le code. Cela fait 4 ans que je travaille sur la _codebase_ de Gitlab et voir d'où les bugs pourraient émerger est devenu une seconde nature pour moi.

 

## 4\. Chercher à comprendre : Poser des questions

Il est simple de suggérer des changements dans le code que je passe en revue mais parfois ce que je suggère n'est peut-être pas juste. Il est important qu'au lieu de juste suggérer un changement, vous vous demandiez toujours si l'auteur pense que c'est le bon changement. Discuter d'un changement aide l'examinateur et l'auteur à comprendre le code déjà existant ainsi que le code étant suggéré. Peut-être que la suggestion avait déjà été testée par l'auteur. Être ouvert à la discussion aide à obtenir la bonne solution.

Cependant, il arrive parfois que des suggestions de changements soient faites autour du _legacy code_, c'est à dire du code qui existe depuis longtemps sans avoir été mis à jour pour la documentation. Dans des cas, la conclusion peut être que de la dette technique ne soit crée. Ce n'est pas grave. Nous devrions chercher des [solutions ennuyeuses](https://about.gitlab.com/handbook/values/#boring-solutions) en premier mais aussi comprendre qu'une solution plus optimale ne soit nécessaire à l'avenir.

 

## Pour résumer

Passer en revue du code efficacement est une compétence qui s'apprend en pratiquant. Prendre le temps de trouver un flux de travail qui vous correspond est aussi important. Au fil des années où j'ai fais des revues de code, je me suis astreint à ces astuces. Pourtant, je suis loin d'être parfait; je suis constamment en train d'apprendre de nouvelles et des manières différentes d'optimiser mon flux de travail pour la revue de code. J'adorerais entendre d'autres conseils et d'autres flux de travail. C'est grâce aux discussions que nous pouvons nous améliorer et nous pousser à être les meilleurs possibles.

 

Vous cherchez des utilisateurs ou une instance GitLab hébergée en France ? **[Rejoignez la Communautés Froggit](http://froggit.fr/)**.

 

**Crédits** [![](../images/by-sa.png)](https://creativecommons.org/licenses/by-sa/4.0/deed.fr) Le contenu de cet article est en Licence Libre Creative Commons Cet article est une traduction [issue du site de GitLab.](https://about.gitlab.com/blog/2020/04/24/parent-child-pipelines)
