---
title: "Comment les variables CI/CD pré-remplies faciliteront le fonctionnement des pipelines"
date: "2021-05-26"
authors: "aboudreault"
slug: "comment-les-variables-ci-cd-pre-remplies-faciliteront-le-fonctionnement-des-pipelines"
tags: 
  - "ci-cd"
  - "gitlab"
  - "devops"
  - "froggit"
  - "integration-continue"
image: "multi-project-pipelines.jpg"
---

#### Apprenez-en plus sur cette future version et sur la manière dont les variables pré-remplies permettront de gagner du temps et des réduire les erreurs.
 <!-- truncate -->
![](../images/multi-project-pipelines.jpg)

[Les variables CI/CD](https://about.gitlab.com/topics/ci-cd/) sont une façon utile de personnaliser les pipelines selon leur environnement. Mais comment faire lorsque vous avez besoin d'outrepasser une variable ou que vous avez besoin de faire fonctionner un pipeline manuellement ? Ces scénarios peuvent poser problème.

- Comment faire lorsque vous ne savez pas quelles variables / valeurs mettre ?
- Que se passe t-il si vous faites une erreur ?

Avoir à saisir manuellement des variables et des valeurs est fastidieux et sujet à erreur. De plus, un utilisateur ne connaît pas forcément toutes les différentes valeurs / variables qu'il a besoin d'entrer. Dans GitLab 13.7, ils ont ajouté une fonctionnalité qui vous aide à résoudre ces problèmes en générant des variables pré-remplies à partir de votre fichier `.gitlab-ci.yml.` quand vous exécutez un pipeline.

 

## Qu'est ce que les variables CI/CD ?

[Les variables CI/CD](https://docs.gitlab.com/ee/ci/variables/README.html) sont des valeurs dynamiques assignées à des environnements. Ces variables d'environnement affectent la manière dont les processus en cours d'exécution se comportent sur un système d'exploitation. Les variables permettent aux équipes de customiser des tâches dans GitLab CI/CD.

Il y a deux endroits où les équipes peuvent définir les variables :

\-> Le fichier `.gitlab-ci.yml.` -> Le fichier GitLab Runner `config.toml.`

Les variables CI/CD peuvent être très utiles, mais comment faire si vous avez besoin d'outrepasser une variables ou d'exécuter un pipeline manuellement ? Vous pourriez faire ça si les résultats de pipeline (par exemple, une compilation de code) sont requis en dehors de l'exécution normale du pipeline. Les équipes pourraient aussi opter pour des déploiements manuels en production et le besoin d'arrêter le pipeline de manière prématurée. Exécuter un pipeline manuellement n'est pas inhabituel mais [définir les variables](https://docs.gitlab.com/ee/ci/variables/where_variables_can_be_used.html) et les rentrer dans un pipeline manuel n'a pas toujours été un processus simple.

 

 

Premièrement, les équipes ont besoin d’exécuter un pipeline / une tâche manuellement et ensuite naviguent dans la vue d'ensemble. Ensuite, ils doivent sélectionner toutes les variables requises à partir du menu déroulant sur la page “_Run Pipeline_”. Si les développeurs ne connaissent pas toutes les variables nécessaires par cœur, ils vont devoir vérifier leurs sources et faire des allers-retours. Si il y a de nombreuses paires clés / valeurs à entrer, cela peut être particulièrement laborieux.

## Les variables pré-remplies : Qu'est-ce que c'est ?

Dans la 13.7, ils ont lancés une fonctionnalité qui va simplifier ce processus. A présent, le formulaire “_Run pipeline_” va [générer des variables pré-remplies](https://gitlab.com/gitlab-org/gitlab/-/issues/30101) pour votre pipeline en fonction des définitions de variables dans votre fichier `.gitlab-ci.yml`.La réponse à cette fonctionnalité de la part de la communauté GitLab fût enthousiaste.

![pre-filled variables issue](../images/pre-filled-variables.png)

## _Les gens sont enthousiasmés par les variables pré-remplies !_

## Les bénéfices des variables pré-remplies

L’intérêt des variables pré-remplies est d’accroître l'efficacité et de réduire les petites frustrations qui rendent les tâches plus difficiles qu'elles ne devraient.

Les variables pré-remplies vont réduire :

- Les frustrations liées aux valeurs de menus-déroulants
- Les frictions liées au choix de mauvaises valeurs
- Re-exécuter et débugger les pipelines à cause de mauvaises valeurs
- Les erreurs et les actions cliquables

 

\[caption id="" align="aligncenter" width="1280"\]![](../images/Run-pipeline.gif) Les variables pré-remplies en action\[/caption\]

 

Pour les équipes qui déploient manuellement en production, les variables pré-remplies vont faciliter cette étape de révision, de sorte que tout personne disposant des bonnes autorisations va pouvoir déclencher manuellement le pipeline de déploiement. Si le relecteur à besoin de faire une exception, il peut aussi outrepasser une variable si c'est nécessaire.

 

Les variables pré-remplies vont aider les équipes à gagner du temps, réduire les erreurs et rendre le processus de pipeline manuel plus souple. Pensez-vous que nous avons raté quelque chose ou qu'il y a de meilleurs manières de fluidifier encore ce processus ? Laissez un commentaire et dites nous ce que vous en pensez. Tout le monde peut contribuer.

 

## Les futures sorties GitLab CI

Les variables pré-remplies sont seulement une des fonctionnalités d'intégration continue. Les équipes de GitLab sortent de [nouvelles fonctionnalités](https://about.gitlab.com/upcoming-releases/) le 22 chaque mois et n'importe qui peut contribuer sur ces sujets.

 

## En savoir plus sur CI / CD

- [Vous voulez un pipeline CI / CD plus efficace? Essayez nos conseils de pro](https://about.gitlab.com/blog/2020/07/29/effective-ci-cd-pipelines/)
- [Webcast: 7 hacks CI / CD](https://about.gitlab.com/webcast/7cicd-hacks/)
- [Comment utiliser les modèles de pipeline CI / CD de GitLab](https://about.gitlab.com/blog/2020/09/23/get-started-ci-pipeline-templates/)

 

Vous cherchez des utilisateurs ou une instance GitLab hébergée en France ? **[Rejoignez la Communautés Froggit](http://froggit.fr/)**.

 

**Crédits** [![](../images/by-sa.png)](https://creativecommons.org/licenses/by-sa/4.0/deed.fr) Le contenu de cet article est en Licence Libre Creative Commons Cet article est une traduction [issue du site de GitLab.](https://about.gitlab.com/blog/2020/10/30/mitigating-the-impact-of-docker-hub-pull-requests-limits/)
